@@ -334,7 +334,7 @@ PHYSFS_COMPILE_TIME_ASSERT(sint64, sizeof(PHYSFS_sint64) == 8);
  * \sa PHYSFS_setBuffer
  * \sa PHYSFS_flush
  */
-typedef struct
+typedef struct PHYSFS_File
 {
     void *opaque;  /**< That's all you get. Don't touch. */
 } PHYSFS_File;
@@ -369,7 +369,7 @@ typedef struct
  *
  * \sa PHYSFS_supportedArchiveTypes
  */
-typedef struct
+typedef struct PHYSFS_ArchiveInfo
 {
     const char *extension;   /**< Archive file extension: "ZIP", for example. */
     const char *description; /**< Human-readable archive description. */
@@ -391,7 +391,7 @@ typedef struct
  * \sa PHYSFS_VERSION
  * \sa PHYSFS_getLinkedVersion
  */
-typedef struct
+typedef struct PHYSFS_Version
 {
     PHYSFS_uint8 major; /**< major revision */
     PHYSFS_uint8 minor; /**< minor revision */
@@ -399,9 +399,9 @@ typedef struct
 } PHYSFS_Version;
 
 #ifndef DOXYGEN_SHOULD_IGNORE_THIS
-#define PHYSFS_VER_MAJOR 1
-#define PHYSFS_VER_MINOR 1
-#define PHYSFS_VER_PATCH 1
+#define PHYSFS_VER_MAJOR 2
+#define PHYSFS_VER_MINOR 0
+#define PHYSFS_VER_PATCH 0
 #endif  /* DOXYGEN_SHOULD_IGNORE_THIS */
 
 
@@ -498,8 +498,9 @@ __EXPORT__ int PHYSFS_init(const char *argv0);
  *  handle a specific failure.
  *
  * Once successfully deinitialized, PHYSFS_init() can be called again to
- *  restart the subsystem. All defaults API states are restored at this
- *  point.
+ *  restart the subsystem. All default API states are restored at this
+ *  point, with the exception of any custom allocator you might have
+ *  specified, which survives between initializations.
  *
  *  \return nonzero on success, zero on error. Specifics of the error can be
  *          gleaned from PHYSFS_getLastError(). If failure, state of PhysFS is
@@ -530,7 +531,7 @@ __EXPORT__ int PHYSFS_deinit(void);
  * for (i = PHYSFS_supportedArchiveTypes(); *i != NULL; i++)
  * {
  *     printf("Supported archive: [%s], which is [%s].\n",
- *              i->extension, i->description);
+ *              (*i)->extension, (*i)->description);
  * }
  * \endcode
  *
@@ -1973,7 +1974,7 @@ __EXPORT__ int PHYSFS_symbolicLinksPermitted(void);
  *
  * \sa PHYSFS_setAllocator
  */
-typedef struct
+typedef struct PHYSFS_Allocator
 {
     int (*Init)(void);   /**< Initialize. Can be NULL. Zero on failure. */
     void (*Deinit)(void);  /**< Deinitialize your allocator. Can be NULL. */
